/*
    SPDX-FileCopyrightText: 2009 Laurent Montel <montel@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef KDFUTIL_H
#define KDFUTIL_H

static const float Full_Percent = 95.0;

#endif
