/****************************************************************************
** Meta object code from reading C++ file 'disks.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdf-26.08.0/src/disks.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'disks.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DiskEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto DiskEntry::qt_create_metaobjectdata<qt_meta_tag_ZN9DiskEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiskEntry",
        "sysCallError",
        "",
        "DiskEntry*",
        "disk",
        "err_no",
        "deviceNameChanged",
        "mountPointChanged",
        "mountOptionsChanged",
        "fsTypeChanged",
        "mountedChanged",
        "kBSizeChanged",
        "kBUsedChanged",
        "kBAvailChanged",
        "iconNameChanged",
        "toggleMount",
        "mount",
        "umount",
        "remount",
        "setMountCommand",
        "mnt",
        "setUmountCommand",
        "umnt",
        "setDeviceName",
        "deviceName",
        "setMountPoint",
        "mountPoint",
        "setIconName",
        "iconName",
        "setIconToDefault",
        "setMountOptions",
        "mountOptions",
        "setFsType",
        "fsType",
        "setMounted",
        "nowMounted",
        "setKBSize",
        "kb_size",
        "setKBUsed",
        "kb_used",
        "setKBAvail",
        "kb_avail",
        "guessIconName",
        "receivedSysStdErrOut"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sysCallError'
        QtMocHelpers::SignalData<void(DiskEntry *, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'deviceNameChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mountPointChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mountOptionsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fsTypeChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mountedChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kBSizeChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kBUsedChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kBAvailChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconNameChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleMount'
        QtMocHelpers::SlotData<int()>(15, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'mount'
        QtMocHelpers::SlotData<int()>(16, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'umount'
        QtMocHelpers::SlotData<int()>(17, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'remount'
        QtMocHelpers::SlotData<int()>(18, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setMountCommand'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'setUmountCommand'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setDeviceName'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setMountPoint'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setIconName'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setIconToDefault'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMountOptions'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'setFsType'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'setMounted'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'setKBSize'
        QtMocHelpers::SlotData<void(qulonglong)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 37 },
        }}),
        // Slot 'setKBUsed'
        QtMocHelpers::SlotData<void(qulonglong)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 39 },
        }}),
        // Slot 'setKBAvail'
        QtMocHelpers::SlotData<void(qulonglong)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 41 },
        }}),
        // Slot 'guessIconName'
        QtMocHelpers::SlotData<QString()>(42, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'receivedSysStdErrOut'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DiskEntry, qt_meta_tag_ZN9DiskEntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DiskEntry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DiskEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DiskEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DiskEntryE_t>.metaTypes,
    nullptr
} };

void DiskEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiskEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sysCallError((*reinterpret_cast<std::add_pointer_t<DiskEntry*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->deviceNameChanged(); break;
        case 2: _t->mountPointChanged(); break;
        case 3: _t->mountOptionsChanged(); break;
        case 4: _t->fsTypeChanged(); break;
        case 5: _t->mountedChanged(); break;
        case 6: _t->kBSizeChanged(); break;
        case 7: _t->kBUsedChanged(); break;
        case 8: _t->kBAvailChanged(); break;
        case 9: _t->iconNameChanged(); break;
        case 10: { int _r = _t->toggleMount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->mount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->umount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->remount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setMountCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->setUmountCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->setDeviceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->setMountPoint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->setIconName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->setIconToDefault(); break;
        case 20: _t->setMountOptions((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->setFsType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setMounted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setKBSize((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 24: _t->setKBUsed((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 25: _t->setKBAvail((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 26: { QString _r = _t->guessIconName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->receivedSysStdErrOut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DiskEntry* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)(DiskEntry * , int )>(_a, &DiskEntry::sysCallError, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::deviceNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::mountPointChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::mountOptionsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::fsTypeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::mountedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::kBSizeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::kBUsedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::kBAvailChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEntry::*)()>(_a, &DiskEntry::iconNameChanged, 9))
            return;
    }
}

const QMetaObject *DiskEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiskEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DiskEntryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DiskEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void DiskEntry::sysCallError(DiskEntry * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DiskEntry::deviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DiskEntry::mountPointChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DiskEntry::mountOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DiskEntry::fsTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DiskEntry::mountedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DiskEntry::kBSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DiskEntry::kBUsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DiskEntry::kBAvailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DiskEntry::iconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
