/********************************************************************************
** Form generated from reading UI file 'mntconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MNTCONFIG_H
#define UI_MNTCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kiconbutton.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_MntConfigWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *mGroupBox;
    QGridLayout *gridLayout_2;
    QLabel *iconNameLabel;
    QLabel *mountLabel;
    QLabel *umountLabel;
    QPushButton *mDefaultIconButton;
    QPushButton *mMountButton;
    QPushButton *mUmountButton;
    KIconButton *mIconButton;
    KLineEdit *mIconLineEdit;
    KLineEdit *mMountLineEdit;
    KLineEdit *mUmountLineEdit;
    QTreeWidget *m_listWidget;

    void setupUi(QWidget *MntConfigWidget)
    {
        if (MntConfigWidget->objectName().isEmpty())
            MntConfigWidget->setObjectName("MntConfigWidget");
        MntConfigWidget->resize(550, 350);
        gridLayout = new QGridLayout(MntConfigWidget);
        gridLayout->setObjectName("gridLayout");
        mGroupBox = new QGroupBox(MntConfigWidget);
        mGroupBox->setObjectName("mGroupBox");
        gridLayout_2 = new QGridLayout(mGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        iconNameLabel = new QLabel(mGroupBox);
        iconNameLabel->setObjectName("iconNameLabel");
        iconNameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(iconNameLabel, 1, 0, 1, 1);

        mountLabel = new QLabel(mGroupBox);
        mountLabel->setObjectName("mountLabel");
        mountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(mountLabel, 4, 0, 1, 1);

        umountLabel = new QLabel(mGroupBox);
        umountLabel->setObjectName("umountLabel");
        umountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(umountLabel, 6, 0, 1, 1);

        mDefaultIconButton = new QPushButton(mGroupBox);
        mDefaultIconButton->setObjectName("mDefaultIconButton");

        gridLayout_2->addWidget(mDefaultIconButton, 1, 3, 1, 1);

        mMountButton = new QPushButton(mGroupBox);
        mMountButton->setObjectName("mMountButton");

        gridLayout_2->addWidget(mMountButton, 4, 3, 1, 1);

        mUmountButton = new QPushButton(mGroupBox);
        mUmountButton->setObjectName("mUmountButton");

        gridLayout_2->addWidget(mUmountButton, 6, 3, 1, 1);

        mIconButton = new KIconButton(mGroupBox);
        mIconButton->setObjectName("mIconButton");

        gridLayout_2->addWidget(mIconButton, 1, 2, 1, 1);

        mIconLineEdit = new KLineEdit(mGroupBox);
        mIconLineEdit->setObjectName("mIconLineEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mIconLineEdit->sizePolicy().hasHeightForWidth());
        mIconLineEdit->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(mIconLineEdit, 1, 1, 1, 1);

        mMountLineEdit = new KLineEdit(mGroupBox);
        mMountLineEdit->setObjectName("mMountLineEdit");

        gridLayout_2->addWidget(mMountLineEdit, 4, 1, 1, 2);

        mUmountLineEdit = new KLineEdit(mGroupBox);
        mUmountLineEdit->setObjectName("mUmountLineEdit");

        gridLayout_2->addWidget(mUmountLineEdit, 6, 1, 1, 2);


        gridLayout->addWidget(mGroupBox, 1, 0, 1, 1);

        m_listWidget = new QTreeWidget(MntConfigWidget);
        m_listWidget->setObjectName("m_listWidget");
        m_listWidget->setRootIsDecorated(false);

        gridLayout->addWidget(m_listWidget, 0, 0, 1, 1);


        retranslateUi(MntConfigWidget);

        QMetaObject::connectSlotsByName(MntConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *MntConfigWidget)
    {
        iconNameLabel->setText(tr2i18n("Icon name:", nullptr));
        mountLabel->setText(tr2i18n("Mount Command:", nullptr));
        umountLabel->setText(tr2i18n("Unmount Command:", nullptr));
        mDefaultIconButton->setText(tr2i18n("Default Icon", nullptr));
        mMountButton->setText(tr2i18n("Get Command...", nullptr));
        mUmountButton->setText(tr2i18n("Get Command...", nullptr));
        (void)MntConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class MntConfigWidget: public Ui_MntConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MNTCONFIG_H

