/********************************************************************************
** Form generated from reading UI file 'kdfconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KDFCONFIG_H
#define UI_KDFCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KDFConfigWidget
{
public:
    QGridLayout *gridLayout;
    QTreeWidget *m_listWidget;
    QLabel *updateLabel;
    QSpinBox *m_updateSpinBox;
    QCheckBox *mOpenMountCheck;
    QCheckBox *mPopupFullCheck;
    QCheckBox *mSystemFileManagerCheck;
    QLabel *fileManagerEdit;
    KLineEdit *mFileManagerEdit;
    QLabel *mFlatpakLabel;

    void setupUi(QWidget *KDFConfigWidget)
    {
        if (KDFConfigWidget->objectName().isEmpty())
            KDFConfigWidget->setObjectName("KDFConfigWidget");
        KDFConfigWidget->resize(550, 350);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KDFConfigWidget->sizePolicy().hasHeightForWidth());
        KDFConfigWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(KDFConfigWidget);
        gridLayout->setObjectName("gridLayout");
        m_listWidget = new QTreeWidget(KDFConfigWidget);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        m_listWidget->setHeaderItem(__qtreewidgetitem);
        m_listWidget->setObjectName("m_listWidget");
        m_listWidget->setRootIsDecorated(false);

        gridLayout->addWidget(m_listWidget, 0, 0, 1, 2);

        updateLabel = new QLabel(KDFConfigWidget);
        updateLabel->setObjectName("updateLabel");

        gridLayout->addWidget(updateLabel, 1, 0, 1, 1);

        m_updateSpinBox = new QSpinBox(KDFConfigWidget);
        m_updateSpinBox->setObjectName("m_updateSpinBox");
        m_updateSpinBox->setMaximum(3600);
        m_updateSpinBox->setValue(60);

        gridLayout->addWidget(m_updateSpinBox, 1, 1, 1, 1);

        mOpenMountCheck = new QCheckBox(KDFConfigWidget);
        mOpenMountCheck->setObjectName("mOpenMountCheck");

        gridLayout->addWidget(mOpenMountCheck, 6, 0, 1, 2);

        mPopupFullCheck = new QCheckBox(KDFConfigWidget);
        mPopupFullCheck->setObjectName("mPopupFullCheck");

        gridLayout->addWidget(mPopupFullCheck, 7, 0, 1, 2);

        mSystemFileManagerCheck = new QCheckBox(KDFConfigWidget);
        mSystemFileManagerCheck->setObjectName("mSystemFileManagerCheck");

        gridLayout->addWidget(mSystemFileManagerCheck, 2, 0, 1, 2);

        fileManagerEdit = new QLabel(KDFConfigWidget);
        fileManagerEdit->setObjectName("fileManagerEdit");

        gridLayout->addWidget(fileManagerEdit, 3, 0, 1, 1);

        mFileManagerEdit = new KLineEdit(KDFConfigWidget);
        mFileManagerEdit->setObjectName("mFileManagerEdit");

        gridLayout->addWidget(mFileManagerEdit, 3, 1, 1, 1);

        mFlatpakLabel = new QLabel(KDFConfigWidget);
        mFlatpakLabel->setObjectName("mFlatpakLabel");
        mFlatpakLabel->setVisible(false);
        QFont font;
        font.setItalic(true);
        mFlatpakLabel->setFont(font);

        gridLayout->addWidget(mFlatpakLabel, 4, 0, 1, 2);


        retranslateUi(KDFConfigWidget);

        QMetaObject::connectSlotsByName(KDFConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *KDFConfigWidget)
    {
        updateLabel->setText(tr2i18n("Update frequency:", nullptr));
        m_updateSpinBox->setSuffix(tr2i18n(" sec", nullptr));
        mOpenMountCheck->setText(tr2i18n("Open file manager automatically on mount", nullptr));
        mPopupFullCheck->setText(tr2i18n("Pop up a window when a disk gets critically full", nullptr));
        mSystemFileManagerCheck->setText(tr2i18n("Use system default file manager", nullptr));
        fileManagerEdit->setText(tr2i18n("File manager (e.g. konsole -e mc %m):", nullptr));
        mFlatpakLabel->setText(tr2i18n("Custom file manager not supported when running as Flatpak.", nullptr));
        (void)KDFConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class KDFConfigWidget: public Ui_KDFConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KDFCONFIG_H

